Welcome to Khoj

# Your AI Knowledge Assistant

Hi {{name}}! We are psyched to be part of your journey with personal AI. To better help you, we're committed to staying transparent, accessible, and completely open-source.

Start Thinking

### Your new search bar

Get straight to the answers you're looking for, grounded in reliable and high quality sources.

### Craft your team

Get specialized assistance (market analysis, health concerns, environmental research), with custom and curated agents. You get a whole team of AIs, always available.

### Bring your own data

Build on top of your own knowledge base. Khoj stores whatever documents you share with it, so you can get answers from your personal data in your native language.

### Do deep research

Go beyond a single query. Let Khoj run for longer and perform in-depth analyses tailored to your needs.

Got feedback? Reply to this email and say hi to introduce yourself 👋🏽.

- The Khoj Team
Docs GitHub Twitter LinkedIn Discord